==> brainfall-0.1.0-py3-none-any.whl: brainfall/markets/__init__.py <==
from collections.abc import Callable

from binance.spot import Spot
from binance.websocket.spot.websocket_client import (
    SpotWebsocketClient as WebsocketClient,
)
from pendulum import DateTime

from brainfall.models import HistoricalData, KlineSocketData, MarketInfo
from brainfall.utils.converters import ms_ts_to_datetime


class Binance:
    SUPPORTED_INTERVALS = [
        "1m",
        "3m",
        "5m",
        "15m",
        "30m",
        "1h",
        "2h",
        "4h",
        "6h",
        "8h",
        "12h",
        "1d",
        "3d",
        "1w",
        "1M",
    ]
    KLINES_COLS = [
        "open_time",
        "open_price",
        "high_price",
        "low_price",
        "close_price",
        "volume",
        "close_time",
        "quote_asset_volume",
        "num_trades",
        "taker_buy_base_asset_volume",
        "taker_buy_quote_asset_volume",
        "ignore",
    ]

    def __init__(self, **kwargs):
        self.client = Spot(**kwargs)
        self.ws_client = WebsocketClient()
        self.ws_client.start()
        self._active_ws = 0

    def server_time(self) -> DateTime | None:
        time = self.client.time().get("serverTime")
        return ms_ts_to_datetime(time) if time else None

    def klines(self, symbol: str, interval: str, **kwargs) -> HistoricalData:
        klines = self.client.klines(symbol=symbol, interval=interval, **kwargs)
        return HistoricalData(
            **{key: val for key, val in zip(self.KLINES_COLS, zip(*klines))}
        )  # old->new

    def start_kline_socket(
        self, symbol: str, interval: str, callback: Callable
    ) -> None:
        wrapped_callback = self._kline_socket_callback_wrapper(callback)
        self.ws_client.kline(
            callback=wrapped_callback,
            symbol=symbol,
            interval=interval,
            id=self._active_ws + 1,
        )
        self._active_ws += 1

    def stop_kline_socket(self, symbol: str, interval: str) -> None:
        self.ws_client.stop_socket(f"{symbol.lower()}@kline_{interval}")

    def market_info(self) -> MarketInfo:
        return MarketInfo(**self.client.exchange_info())

    def stop(self) -> None:
        self.ws_client.stop()

    @staticmethod
    def _kline_socket_callback_wrapper(func: Callable) -> Callable:
        def _socket_callback_wrapper(msg):
            if "result" in msg:
                return
            nested_msg = msg.pop("k", {})
            msg.update(nested_msg)
            data = KlineSocketData(**msg)
            return func(data)

        return _socket_callback_wrapper

==> brainfall-0.1.1-py3-none-any.whl: brainfall/markets/__init__.py <==
from collections.abc import Callable

from binance.spot import Spot
from binance.websocket.spot.websocket_client import (
    SpotWebsocketClient as WebsocketClient,
)
from pendulum import DateTime

from brainfall.models.binance import HistoricalData, KlineSocketData, MarketInfo
from brainfall.utils.converters import ms_ts_to_datetime


class Binance:
    SUPPORTED_INTERVALS = [
        "1m",
        "3m",
        "5m",
        "15m",
        "30m",
        "1h",
        "2h",
        "4h",
        "6h",
        "8h",
        "12h",
        "1d",
        "3d",
        "1w",
        "1M",
    ]
    KLINES_COLS = [
        "open_time",
        "open_price",
        "high_price",
        "low_price",
        "close_price",
        "volume",
        "close_time",
        "quote_asset_volume",
        "num_trades",
        "taker_buy_base_asset_volume",
        "taker_buy_quote_asset_volume",
        "ignore",
    ]

    def __init__(self, **kwargs):
        self.client = Spot(**kwargs)
        self.ws_client = WebsocketClient()
        self.ws_client.start()
        self._active_ws = 0

    def server_time(self) -> DateTime | None:
        time = self.client.time().get("serverTime")
        return ms_ts_to_datetime(time) if time else None

    def klines(self, symbol: str, interval: str, **kwargs) -> HistoricalData:
        klines = self.client.klines(symbol=symbol, interval=interval, **kwargs)
        return HistoricalData(
            **{key: val for key, val in zip(self.KLINES_COLS, zip(*klines))}
        )  # old->new

    def start_kline_socket(
        self, symbol: str, interval: str, callback: Callable
    ) -> None:
        wrapped_callback = self._kline_socket_callback_wrapper(callback)
        self.ws_client.kline(
            callback=wrapped_callback,
            symbol=symbol,
            interval=interval,
            id=self._active_ws + 1,
        )
        self._active_ws += 1

    def stop_kline_socket(self, symbol: str, interval: str) -> None:
        self.ws_client.stop_socket(f"{symbol.lower()}@kline_{interval}")

    def market_info(self) -> MarketInfo:
        return MarketInfo(**self.client.exchange_info())

    def stop(self) -> None:
        self.ws_client.stop()

    @staticmethod
    def _kline_socket_callback_wrapper(func: Callable) -> Callable:
        def _socket_callback_wrapper(msg):
            if "result" in msg:
                return
            nested_msg = msg.pop("k", {})
            msg.update(nested_msg)
            data = KlineSocketData(**msg)
            return func(data)

        return _socket_callback_wrapper
